( cd usr/bin ; rm -rf gnome-character-map )
( cd usr/bin ; ln -sf gucharmap gnome-character-map )
( cd usr/bin ; rm -rf charmap )
( cd usr/bin ; ln -sf gucharmap charmap )
( cd usr/lib64 ; rm -rf libgucharmap.so )
( cd usr/lib64 ; ln -sf libgucharmap.so.6.0.1 libgucharmap.so )
( cd usr/lib64 ; rm -rf libgucharmap.so.6 )
( cd usr/lib64 ; ln -sf libgucharmap.so.6.0.1 libgucharmap.so.6 )
